@@ -4,6 +4,7 @@ This file has several validators used on cornflow core
 import re
 from typing import Tuple, Union
 
+from jsonschema import Draft7Validator
 from marshmallow import ValidationError
 from cornflow_core.exceptions import InvalidUsage
 from disposable_email_domains import blocklist
@@ -79,3 +80,24 @@ def validate_and_continue(obj, data):
     if validate is None:
         raise InvalidUsage(error=f"Bad data format: {err}")
     return validate
+
+
+def json_schema_validate(schema: dict, data: dict) -> list:
+    """
+    Method to validate some data against a json schema
+
+    :param dict schema:the json schema in dict format.
+    :param dict data: the data to validate in dict format
+    :return: a list with the errors found
+    :rtype: list
+    """
+    validator = Draft7Validator(schema)
+    if not validator.is_valid(data):
+        return [e for e in validator.iter_errors(data)]
+    return []
+
+
+"""
+Aliases
+"""
+marshmallow_validate_and_continue = validate_and_continue
